@@ -1,6 +1,6 @@
 import pytest
 
-from pdfdancer import Color, StandardFonts
+from pdfdancer import Color, StandardFonts, FontType
 from pdfdancer.pdfdancer_v1 import PDFDancer
 from tests.e2e import _require_env_and_fixture
 from tests.e2e.pdf_assertions import PDFAssertions
@@ -28,6 +28,11 @@ def test_find_paragraphs_by_position():
         assert pytest.approx(last.position.x(), rel=0, abs=1) == 54
         assert pytest.approx(last.position.y(), rel=0, abs=2) == 496
 
+        assert last.object_ref().status is not None
+        assert last.object_ref().status.is_encodable()
+        assert last.object_ref().status.font_type == FontType.EMBEDDED
+        assert not last.object_ref().status.is_modified()
+
 
 def test_find_paragraphs_by_text():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
@@ -60,6 +65,11 @@ def test_move_paragraph():
         moved = pdf.page(0).select_paragraphs_at(0.1, 300)[0]
         assert moved is not None
 
+        assert moved.object_ref().status is not None
+        assert moved.object_ref().status.is_encodable()
+        assert moved.object_ref().status.font_type == FontType.EMBEDDED
+        assert not moved.object_ref().status.is_modified()
+
 
 def test_modify_paragraph():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
@@ -76,6 +86,12 @@ def test_modify_paragraph():
             .apply()
         )
 
+        moved = pdf.page(0).select_paragraphs_at(300.1, 500)[0]
+        assert moved.object_ref().status is not None
+        assert moved.object_ref().status.is_encodable()
+        assert moved.object_ref().status.font_type == FontType.STANDARD
+        assert moved.object_ref().status.is_modified()
+
     (
         PDFAssertions(pdf)
         .assert_textline_has_font("Awesomely", "Helvetica", 12)
@@ -136,16 +152,74 @@ def test_modify_paragraph_without_position_and_spacing():
     )
 
 
+def test_modify_paragraph_noop():
+    base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
+
+    with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
+        paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
+        (
+            paragraph.edit()
+            .apply()
+        )
+        paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
+        assert paragraph.object_ref().status is not None
+        assert paragraph.object_ref().status.is_encodable()
+        assert paragraph.object_ref().status.font_type == FontType.EMBEDDED
+        assert not paragraph.object_ref().status.is_modified()
+
+    (
+        PDFAssertions(pdf)
+        .assert_textline_has_font("The Complete", "IXKSWR+Poppins-Bold", 1)
+        .assert_textline_has_color("The Complete", Color(255, 255, 255))
+    )
+
+
+def test_modify_paragraph_only_text():
+    base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
+
+    with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
+        paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
+        result = (
+            paragraph.edit()
+            .replace("lorem\nipsum\nCaesar")
+            .apply()
+        )
+
+        # this should issue a warning about an modified text with an embedded font
+        # the information is right now only available when selecting the paragraph again, that's bad
+        assert result.warning is not None
+        assert "You are using an embedded font and modified the text." in result.warning
+
+        paragraph = pdf.page(0).select_paragraphs_starting_with("lorem")[0]
+        assert paragraph.object_ref().status is not None
+        assert paragraph.object_ref().status.is_encodable()
+        assert paragraph.object_ref().status.font_type == FontType.EMBEDDED
+        assert paragraph.object_ref().status.is_modified()
+
+    (
+        PDFAssertions(pdf)
+        .assert_textline_does_not_exist("The Complete")
+        .assert_textline_has_color("lorem", Color(255, 255, 255))
+        .assert_textline_has_color("ipsum", Color(255, 255, 255))
+        .assert_textline_has_color("Caesar", Color(255, 255, 255))
+    )
+
+
 def test_modify_paragraph_only_font():
     base_url, token, pdf_path = _require_env_and_fixture("ObviouslyAwesome.pdf")
 
     with PDFDancer.open(pdf_path, token=token, base_url=base_url, timeout=30.0) as pdf:
         paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
-    (
-        paragraph.edit()
-        .font("Helvetica", 28)
-        .apply()
-    )
+        (
+            paragraph.edit()
+            .font("Helvetica", 28)
+            .apply()
+        )
+        paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
+        assert paragraph.object_ref().status is not None
+        assert paragraph.object_ref().status.is_encodable()
+        assert paragraph.object_ref().status.font_type == FontType.STANDARD
+        assert paragraph.object_ref().status.is_modified()
 
     # TODO does not preserve color and fucks up line spacings
     (
@@ -167,6 +241,12 @@ def test_modify_paragraph_only_move():
             .apply()
         )
 
+        paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
+        assert paragraph.object_ref().status is not None
+        assert paragraph.object_ref().status.is_encodable()
+        assert paragraph.object_ref().status.font_type == FontType.EMBEDDED
+        assert paragraph.object_ref().status.is_modified()  # This should actually not be marked as 'modified' but since we are using a ModifyObject operation we are not (yet) able to detect this
+
     (
         PDFAssertions(pdf)
         .assert_textline_has_font("The Complete", "IXKSWR+Poppins-Bold", 1)
@@ -182,13 +262,19 @@ def test_modify_paragraph_simple():
         paragraph = pdf.page(0).select_paragraphs_starting_with("The Complete")[0]
         paragraph.edit().replace("Awesomely\nObvious!").apply()
 
-        (
-            PDFAssertions(pdf)
-            .assert_textline_has_font("Awesomely", "IXKSWR+Poppins-Bold", 1)
-            .assert_textline_has_font("Obvious!", "IXKSWR+Poppins-Bold", 1)
-            .assert_textline_has_color("Awesomely", Color(255, 255, 255))
-            .assert_textline_has_color("Obvious!", Color(255, 255, 255))
-        )
+        paragraph = pdf.page(0).select_paragraphs_starting_with("Awesomely")[0]
+        assert paragraph.object_ref().status is not None
+        assert paragraph.object_ref().status.is_encodable()
+        assert paragraph.object_ref().status.font_type == FontType.EMBEDDED
+        assert paragraph.object_ref().status.is_modified()
+
+    (
+        PDFAssertions(pdf)
+        .assert_textline_has_font("Awesomely", "IXKSWR+Poppins-Bold", 1)
+        .assert_textline_has_font("Obvious!", "IXKSWR+Poppins-Bold", 1)
+        .assert_textline_has_color("Awesomely", Color(255, 255, 255))
+        .assert_textline_has_color("Obvious!", Color(255, 255, 255))
+    )
 
 
 def test_add_paragraph_with_custom_font1_expect_not_found():
